==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/plugin/XPluginManager.hpp <==
#ifndef _COM_SUN_STAR_PLUGIN_XPLUGINMANAGER_HPP_
#define _COM_SUN_STAR_PLUGIN_XPLUGINMANAGER_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_PLUGIN_XPLUGINMANAGER_HDL_
#include "com/sun/star/plugin/XPluginManager.hdl"
#endif

#ifndef _COM_SUN_STAR_AWT_XTOOLKIT_HPP_
#include "com/sun/star/awt/XToolkit.hpp"
#endif
#ifndef _COM_SUN_STAR_PLUGIN_PLUGINEXCEPTION_HPP_
#include "com/sun/star/plugin/PluginException.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_RUNTIMEEXCEPTION_HPP_
#include "com/sun/star/uno/RuntimeException.hpp"
#endif
#ifndef _COM_SUN_STAR_PLUGIN_PLUGINDESCRIPTION_HPP_
#include "com/sun/star/plugin/PluginDescription.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_XINTERFACE_HPP_
#include "com/sun/star/uno/XInterface.hpp"
#endif
#ifndef _COM_SUN_STAR_AWT_XWINDOWPEER_HPP_
#include "com/sun/star/awt/XWindowPeer.hpp"
#endif
#ifndef _COM_SUN_STAR_PLUGIN_XPLUGINCONTEXT_HPP_
#include "com/sun/star/plugin/XPluginContext.hpp"
#endif
#ifndef _COM_SUN_STAR_PLUGIN_XPLUGIN_HPP_
#include "com/sun/star/plugin/XPlugin.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_SEQUENCE_HXX_
#include "com/sun/star/uno/Sequence.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif

inline const ::com::sun::star::uno::Type& SAL_CALL getCppuType( const ::com::sun::star::uno::Reference< ::com::sun::star::plugin::XPluginManager >* ) SAL_THROW( () )
{
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_INTERFACE, "com.sun.star.plugin.XPluginManager" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
}

::com::sun::star::uno::Type const & ::com::sun::star::plugin::XPluginManager::static_type(void *) {
    return ::getCppuType(static_cast< ::com::sun::star::uno::Reference< ::com::sun::star::plugin::XPluginManager > * >(0));
}

#endif // _COM_SUN_STAR_PLUGIN_XPLUGINMANAGER_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/plugin/XPluginManager.hpp <==
#ifndef _COM_SUN_STAR_PLUGIN_XPLUGINMANAGER_HPP_
#define _COM_SUN_STAR_PLUGIN_XPLUGINMANAGER_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_PLUGIN_XPLUGINMANAGER_HDL_
#include "com/sun/star/plugin/XPluginManager.hdl"
#endif

#ifndef _COM_SUN_STAR_AWT_XTOOLKIT_HPP_
#include "com/sun/star/awt/XToolkit.hpp"
#endif
#ifndef _COM_SUN_STAR_PLUGIN_PLUGINEXCEPTION_HPP_
#include "com/sun/star/plugin/PluginException.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_RUNTIMEEXCEPTION_HPP_
#include "com/sun/star/uno/RuntimeException.hpp"
#endif
#ifndef _COM_SUN_STAR_PLUGIN_PLUGINDESCRIPTION_HPP_
#include "com/sun/star/plugin/PluginDescription.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_XINTERFACE_HPP_
#include "com/sun/star/uno/XInterface.hpp"
#endif
#ifndef _COM_SUN_STAR_AWT_XWINDOWPEER_HPP_
#include "com/sun/star/awt/XWindowPeer.hpp"
#endif
#ifndef _COM_SUN_STAR_PLUGIN_XPLUGINCONTEXT_HPP_
#include "com/sun/star/plugin/XPluginContext.hpp"
#endif
#ifndef _COM_SUN_STAR_PLUGIN_XPLUGIN_HPP_
#include "com/sun/star/plugin/XPlugin.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_SEQUENCE_HXX_
#include "com/sun/star/uno/Sequence.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif

namespace com { namespace sun { namespace star { namespace plugin {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::plugin::XPluginManager const *) {
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_INTERFACE, "com.sun.star.plugin.XPluginManager" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::uno::Reference< ::com::sun::star::plugin::XPluginManager > const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::uno::Reference< ::com::sun::star::plugin::XPluginManager > >::get();
}

::com::sun::star::uno::Type const & ::com::sun::star::plugin::XPluginManager::static_type(void *) {
    return ::getCppuType(static_cast< ::com::sun::star::uno::Reference< ::com::sun::star::plugin::XPluginManager > * >(0));
}

#endif // _COM_SUN_STAR_PLUGIN_XPLUGINMANAGER_HPP_
